@@ -31,6 +31,8 @@ class MultiLayer:
             if len(data) % number_layers != 0:
                 print('Data given to @MultiLayer has not ' + str(number_layers) + ' layers, as stated')
                 exit()
+            print(len(data))
+            print(len(data) // number_layers)
             size = int(np.sqrt(len(data) // number_layers))
             print('Read in ' + str(number_layers) + ' layers with size ' + str(size))
             # PRESET SpinLattice OBJECTS
@@ -162,8 +164,7 @@ class SpinLattice():
             ab_elongation:
         """
         if origin is None:
-            origin = [np.mean(self.X), np.mean(self.Y)]
-        print(f' The center of the skyrmion is placed at {origin}')
+            origin = [round(float(np.mean(self.X)), 4), round(float(np.mean(self.Y)), 4)]
         mag = Magnetisation_Skyrmion(self.X, self.Y, origin, vorticity, helicity, c, w, AFM, uplo, elongation,
                                      angl_elongation, ab_elongation)
         for m in range(len(mag.mz)):
