@@ -9,4 +9,7 @@ This constants library holds the test signatures. Test signatures have different
 # Test Ids Multilayer Test =============================================================================================
 MULTI_PRECISIONWITHOUTDAMPING = 1
 MULTI_PRECISIONWITHDAMPING = 2
-MULTI_DOMAINWALLS_Z = 3
\ No newline at end of file
+MULTI_DOMAINWALLS_Z = 3
+
+# Test Ids Monolayer Tests =============================================================================================
+MONO_MF_FM_MODES = 4
